"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _SyncProvider = _interopRequireDefault(require("./SyncProvider"));

var _github = _interopRequireDefault(require("../services/github"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class GitHubSyncProvider extends _SyncProvider.default {
  async receive() {
    const apiKey = await this.getInsomniaStoreData(GitHubSyncProvider.STORE_KEY_API_KEY);
    if (!apiKey) throw new Error();
    const gistId = await this.getInsomniaStoreData(GitHubSyncProvider.STORE_KEY_GIST_ID);
    if (!gistId) throw new Error();
    const gitHubService = new _github.default(apiKey);
    const gist = await gitHubService.getGist(gistId);
    const file = gist.files['insomnia_data.json'];
    if (!file.truncated) await this.importToInsomnia(file.content);else {
      const rawData = await gitHubService.getByUrl(file.raw_url);
      await this.importToInsomnia(rawData);
    }
  }

  async send() {
    const apiKey = await this.getInsomniaStoreData(GitHubSyncProvider.STORE_KEY_API_KEY);
    if (!apiKey) throw new Error();
    const gistId = await this.getInsomniaStoreData(GitHubSyncProvider.STORE_KEY_GIST_ID);
    const content = await this.exportFromInsomnia();
    const gitHubService = new _github.default(apiKey);

    if (!gistId) {
      const gist = await gitHubService.createGist(content);
      await this.setInsomniaStoreData(GitHubSyncProvider.STORE_KEY_GIST_ID, gist.id);
    } else {
      await gitHubService.updateGist(gistId, content);
    }
  }

}

_defineProperty(GitHubSyncProvider, "STORE_KEY_API_KEY", 'gist-sync:api-key');

_defineProperty(GitHubSyncProvider, "STORE_KEY_GIST_ID", 'gist-sync:gist-key');

var _default = GitHubSyncProvider;
exports.default = _default;