"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _axios = _interopRequireDefault(require("axios"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class GitHubService {
  constructor(token) {
    _defineProperty(this, "api", void 0);

    this.api = _axios.default.create({
      baseURL: 'https://api.github.com/',
      headers: {
        Authorization: `Bearer ${token}`
      }
    });
  }

  async getGists() {
    const response = await this.api.get('/gists');
    const gists = response.data.filter(gist => gist.files['insomnia_data.json']);
    return gists;
  }

  async getGist(gistId) {
    const response = await this.api.get(`/gists/${gistId}`);
    return response.data;
  }

  async getByUrl(url) {
    const response = await this.api.get(url);
    return JSON.stringify(response.data);
  }

  async createGist(content) {
    const response = await this.api.post('/gists', {
      files: {
        'insomnia_data.json': {
          content
        }
      },
      description: 'Insomnia Sync Data',
      public: false
    });
    return response.data;
  }

  async updateGist(gistId, content) {
    const response = await this.api.patch(`/gists/${gistId}`, {
      files: {
        'insomnia_data.json': {
          content
        }
      }
    });
    return response.data;
  }

}

var _default = GitHubService;
exports.default = _default;